==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/release/NpmPublishOptions.java <==
package io.github.cdklabs.projen.release;

/**
 * (experimental) Options for npm release.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.918Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.release.NpmPublishOptions")
@software.amazon.jsii.Jsii.Proxy(NpmPublishOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface NpmPublishOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Options for publishing npm package to AWS CodeArtifact.
     * <p>
     * Default: - undefined
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.release.CodeArtifactOptions getCodeArtifactOptions() {
        return null;
    }

    /**
     * (deprecated) Tags can be used to provide an alias instead of version numbers.
     * <p>
     * For example, a project might choose to have multiple streams of development
     * and use a different tag for each stream, e.g., stable, beta, dev, canary.
     * <p>
     * By default, the <code>latest</code> tag is used by npm to identify the current version
     * of a package, and <code>npm install &lt;pkg&gt;</code> (without any <code>&#64;&lt;version&gt;</code> or <code>&#64;&lt;tag&gt;</code>
     * specifier) installs the latest tag. Typically, projects only use the
     * <code>latest</code> tag for stable release versions, and use other tags for unstable
     * versions such as prereleases.
     * <p>
     * The <code>next</code> tag is used by some projects to identify the upcoming version.
     * <p>
     * Default: "latest"
     * <p>
     * @deprecated Use `npmDistTag` for each release branch instead.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getDistTag() {
        return null;
    }

    /**
     * (experimental) GitHub secret which contains the NPM token to use when publishing packages.
     * <p>
     * Default: - "NPM_TOKEN" or "GITHUB_TOKEN" if `registry` is set to `npm.pkg.github.com`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getNpmTokenSecret() {
        return null;
    }

    /**
     * (experimental) The domain name of the npm package registry.
     * <p>
     * To publish to GitHub Packages, set this value to <code>"npm.pkg.github.com"</code>. In
     * this if <code>npmTokenSecret</code> is not specified, it will default to
     * <code>GITHUB_TOKEN</code> which means that you will be able to publish to the
     * repository's package store. In this case, make sure <code>repositoryUrl</code> is
     * correctly defined.
     * <p>
     * Default: "registry.npmjs.org"
     * <p>
     * Example:
     * <p>
     * <blockquote><pre>
     * // Example automatically generated from non-compiling source. May contain errors.
     * "npm.pkg.github.com"
     * </pre></blockquote>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getRegistry() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NpmPublishOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NpmPublishOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<NpmPublishOptions> {
        io.github.cdklabs.projen.release.CodeArtifactOptions codeArtifactOptions;
        java.lang.String distTag;
        java.lang.String npmTokenSecret;
        java.lang.String registry;

        /**
         * Sets the value of {@link NpmPublishOptions#getCodeArtifactOptions}
         * @param codeArtifactOptions Options for publishing npm package to AWS CodeArtifact.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder codeArtifactOptions(io.github.cdklabs.projen.release.CodeArtifactOptions codeArtifactOptions) {
            this.codeArtifactOptions = codeArtifactOptions;
            return this;
        }

        /**
         * Sets the value of {@link NpmPublishOptions#getDistTag}
         * @param distTag Tags can be used to provide an alias instead of version numbers.
         *                For example, a project might choose to have multiple streams of development
         *                and use a different tag for each stream, e.g., stable, beta, dev, canary.
         *                <p>
         *                By default, the <code>latest</code> tag is used by npm to identify the current version
         *                of a package, and <code>npm install &lt;pkg&gt;</code> (without any <code>&#64;&lt;version&gt;</code> or <code>&#64;&lt;tag&gt;</code>
         *                specifier) installs the latest tag. Typically, projects only use the
         *                <code>latest</code> tag for stable release versions, and use other tags for unstable
         *                versions such as prereleases.
         *                <p>
         *                The <code>next</code> tag is used by some projects to identify the upcoming version.
         * @return {@code this}
         * @deprecated Use `npmDistTag` for each release branch instead.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder distTag(java.lang.String distTag) {
            this.distTag = distTag;
            return this;
        }

        /**
         * Sets the value of {@link NpmPublishOptions#getNpmTokenSecret}
         * @param npmTokenSecret GitHub secret which contains the NPM token to use when publishing packages.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder npmTokenSecret(java.lang.String npmTokenSecret) {
            this.npmTokenSecret = npmTokenSecret;
            return this;
        }

        /**
         * Sets the value of {@link NpmPublishOptions#getRegistry}
         * @param registry The domain name of the npm package registry.
         *                 To publish to GitHub Packages, set this value to <code>"npm.pkg.github.com"</code>. In
         *                 this if <code>npmTokenSecret</code> is not specified, it will default to
         *                 <code>GITHUB_TOKEN</code> which means that you will be able to publish to the
         *                 repository's package store. In this case, make sure <code>repositoryUrl</code> is
         *                 correctly defined.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder registry(java.lang.String registry) {
            this.registry = registry;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NpmPublishOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public NpmPublishOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NpmPublishOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NpmPublishOptions {
        private final io.github.cdklabs.projen.release.CodeArtifactOptions codeArtifactOptions;
        private final java.lang.String distTag;
        private final java.lang.String npmTokenSecret;
        private final java.lang.String registry;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.codeArtifactOptions = software.amazon.jsii.Kernel.get(this, "codeArtifactOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.release.CodeArtifactOptions.class));
            this.distTag = software.amazon.jsii.Kernel.get(this, "distTag", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.npmTokenSecret = software.amazon.jsii.Kernel.get(this, "npmTokenSecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.registry = software.amazon.jsii.Kernel.get(this, "registry", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.codeArtifactOptions = builder.codeArtifactOptions;
            this.distTag = builder.distTag;
            this.npmTokenSecret = builder.npmTokenSecret;
            this.registry = builder.registry;
        }

        @Override
        public final io.github.cdklabs.projen.release.CodeArtifactOptions getCodeArtifactOptions() {
            return this.codeArtifactOptions;
        }

        @Override
        public final java.lang.String getDistTag() {
            return this.distTag;
        }

        @Override
        public final java.lang.String getNpmTokenSecret() {
            return this.npmTokenSecret;
        }

        @Override
        public final java.lang.String getRegistry() {
            return this.registry;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCodeArtifactOptions() != null) {
                data.set("codeArtifactOptions", om.valueToTree(this.getCodeArtifactOptions()));
            }
            if (this.getDistTag() != null) {
                data.set("distTag", om.valueToTree(this.getDistTag()));
            }
            if (this.getNpmTokenSecret() != null) {
                data.set("npmTokenSecret", om.valueToTree(this.getNpmTokenSecret()));
            }
            if (this.getRegistry() != null) {
                data.set("registry", om.valueToTree(this.getRegistry()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.release.NpmPublishOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NpmPublishOptions.Jsii$Proxy that = (NpmPublishOptions.Jsii$Proxy) o;

            if (this.codeArtifactOptions != null ? !this.codeArtifactOptions.equals(that.codeArtifactOptions) : that.codeArtifactOptions != null) return false;
            if (this.distTag != null ? !this.distTag.equals(that.distTag) : that.distTag != null) return false;
            if (this.npmTokenSecret != null ? !this.npmTokenSecret.equals(that.npmTokenSecret) : that.npmTokenSecret != null) return false;
            return this.registry != null ? this.registry.equals(that.registry) : that.registry == null;
        }

        @Override
        public final int hashCode() {
            int result = this.codeArtifactOptions != null ? this.codeArtifactOptions.hashCode() : 0;
            result = 31 * result + (this.distTag != null ? this.distTag.hashCode() : 0);
            result = 31 * result + (this.npmTokenSecret != null ? this.npmTokenSecret.hashCode() : 0);
            result = 31 * result + (this.registry != null ? this.registry.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/release/NpmPublishOptions.java <==
package io.github.cdklabs.projen.release;

/**
 * (experimental) Options for npm release.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.592Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.release.NpmPublishOptions")
@software.amazon.jsii.Jsii.Proxy(NpmPublishOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface NpmPublishOptions extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.release.CommonPublishOptions {

    /**
     * (experimental) Options for publishing npm package to AWS CodeArtifact.
     * <p>
     * Default: - undefined
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.release.CodeArtifactOptions getCodeArtifactOptions() {
        return null;
    }

    /**
     * (deprecated) Tags can be used to provide an alias instead of version numbers.
     * <p>
     * For example, a project might choose to have multiple streams of development
     * and use a different tag for each stream, e.g., stable, beta, dev, canary.
     * <p>
     * By default, the <code>latest</code> tag is used by npm to identify the current version
     * of a package, and <code>npm install &lt;pkg&gt;</code> (without any <code>&#64;&lt;version&gt;</code> or <code>&#64;&lt;tag&gt;</code>
     * specifier) installs the latest tag. Typically, projects only use the
     * <code>latest</code> tag for stable release versions, and use other tags for unstable
     * versions such as prereleases.
     * <p>
     * The <code>next</code> tag is used by some projects to identify the upcoming version.
     * <p>
     * Default: "latest"
     * <p>
     * @deprecated Use <code>npmDistTag</code> for each release branch instead.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.String getDistTag() {
        return null;
    }

    /**
     * (experimental) GitHub secret which contains the NPM token to use when publishing packages.
     * <p>
     * Default: - "NPM_TOKEN" or "GITHUB_TOKEN" if `registry` is set to `npm.pkg.github.com`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getNpmTokenSecret() {
        return null;
    }

    /**
     * (experimental) The domain name of the npm package registry.
     * <p>
     * To publish to GitHub Packages, set this value to <code>"npm.pkg.github.com"</code>. In
     * this if <code>npmTokenSecret</code> is not specified, it will default to
     * <code>GITHUB_TOKEN</code> which means that you will be able to publish to the
     * repository's package store. In this case, make sure <code>repositoryUrl</code> is
     * correctly defined.
     * <p>
     * Default: "registry.npmjs.org"
     * <p>
     * Example:
     * <p>
     * <blockquote><pre>
     * "npm.pkg.github.com"
     * </pre></blockquote>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getRegistry() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NpmPublishOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NpmPublishOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<NpmPublishOptions> {
        io.github.cdklabs.projen.release.CodeArtifactOptions codeArtifactOptions;
        java.lang.String distTag;
        java.lang.String npmTokenSecret;
        java.lang.String registry;
        java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> postPublishSteps;
        java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> prePublishSteps;
        io.github.cdklabs.projen.github.workflows.Tools publishTools;

        /**
         * Sets the value of {@link NpmPublishOptions#getCodeArtifactOptions}
         * @param codeArtifactOptions Options for publishing npm package to AWS CodeArtifact.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder codeArtifactOptions(io.github.cdklabs.projen.release.CodeArtifactOptions codeArtifactOptions) {
            this.codeArtifactOptions = codeArtifactOptions;
            return this;
        }

        /**
         * Sets the value of {@link NpmPublishOptions#getDistTag}
         * @param distTag Tags can be used to provide an alias instead of version numbers.
         *                For example, a project might choose to have multiple streams of development
         *                and use a different tag for each stream, e.g., stable, beta, dev, canary.
         *                <p>
         *                By default, the <code>latest</code> tag is used by npm to identify the current version
         *                of a package, and <code>npm install &lt;pkg&gt;</code> (without any <code>&#64;&lt;version&gt;</code> or <code>&#64;&lt;tag&gt;</code>
         *                specifier) installs the latest tag. Typically, projects only use the
         *                <code>latest</code> tag for stable release versions, and use other tags for unstable
         *                versions such as prereleases.
         *                <p>
         *                The <code>next</code> tag is used by some projects to identify the upcoming version.
         * @return {@code this}
         * @deprecated Use `npmDistTag` for each release branch instead.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder distTag(java.lang.String distTag) {
            this.distTag = distTag;
            return this;
        }

        /**
         * Sets the value of {@link NpmPublishOptions#getNpmTokenSecret}
         * @param npmTokenSecret GitHub secret which contains the NPM token to use when publishing packages.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder npmTokenSecret(java.lang.String npmTokenSecret) {
            this.npmTokenSecret = npmTokenSecret;
            return this;
        }

        /**
         * Sets the value of {@link NpmPublishOptions#getRegistry}
         * @param registry The domain name of the npm package registry.
         *                 To publish to GitHub Packages, set this value to <code>"npm.pkg.github.com"</code>. In
         *                 this if <code>npmTokenSecret</code> is not specified, it will default to
         *                 <code>GITHUB_TOKEN</code> which means that you will be able to publish to the
         *                 repository's package store. In this case, make sure <code>repositoryUrl</code> is
         *                 correctly defined.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder registry(java.lang.String registry) {
            this.registry = registry;
            return this;
        }

        /**
         * Sets the value of {@link NpmPublishOptions#getPostPublishSteps}
         * @param postPublishSteps Steps to execute after executing the publishing command.
         *                         These can be used
         *                         to add/update the release artifacts ot any other tasks needed.
         *                         <p>
         *                         Note that when using this in <code>publishToGitHubReleases</code> this will override steps added via <code>addGitHubPostPublishingSteps</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder postPublishSteps(java.util.List<? extends io.github.cdklabs.projen.github.workflows.JobStep> postPublishSteps) {
            this.postPublishSteps = (java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>)postPublishSteps;
            return this;
        }

        /**
         * Sets the value of {@link NpmPublishOptions#getPrePublishSteps}
         * @param prePublishSteps Steps to execute before executing the publishing command. These can be used to prepare the artifact for publishing if neede.
         *                        These steps are executed after <code>dist/</code> has been populated with the build
         *                        output.
         *                        <p>
         *                        Note that when using this in <code>publishToGitHubReleases</code> this will override steps added via <code>addGitHubPrePublishingSteps</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder prePublishSteps(java.util.List<? extends io.github.cdklabs.projen.github.workflows.JobStep> prePublishSteps) {
            this.prePublishSteps = (java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>)prePublishSteps;
            return this;
        }

        /**
         * Sets the value of {@link NpmPublishOptions#getPublishTools}
         * @param publishTools Additional tools to install in the publishing job.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder publishTools(io.github.cdklabs.projen.github.workflows.Tools publishTools) {
            this.publishTools = publishTools;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NpmPublishOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public NpmPublishOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NpmPublishOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NpmPublishOptions {
        private final io.github.cdklabs.projen.release.CodeArtifactOptions codeArtifactOptions;
        private final java.lang.String distTag;
        private final java.lang.String npmTokenSecret;
        private final java.lang.String registry;
        private final java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> postPublishSteps;
        private final java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> prePublishSteps;
        private final io.github.cdklabs.projen.github.workflows.Tools publishTools;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.codeArtifactOptions = software.amazon.jsii.Kernel.get(this, "codeArtifactOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.release.CodeArtifactOptions.class));
            this.distTag = software.amazon.jsii.Kernel.get(this, "distTag", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.npmTokenSecret = software.amazon.jsii.Kernel.get(this, "npmTokenSecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.registry = software.amazon.jsii.Kernel.get(this, "registry", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.postPublishSteps = software.amazon.jsii.Kernel.get(this, "postPublishSteps", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.workflows.JobStep.class)));
            this.prePublishSteps = software.amazon.jsii.Kernel.get(this, "prePublishSteps", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.workflows.JobStep.class)));
            this.publishTools = software.amazon.jsii.Kernel.get(this, "publishTools", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.workflows.Tools.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.codeArtifactOptions = builder.codeArtifactOptions;
            this.distTag = builder.distTag;
            this.npmTokenSecret = builder.npmTokenSecret;
            this.registry = builder.registry;
            this.postPublishSteps = (java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>)builder.postPublishSteps;
            this.prePublishSteps = (java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>)builder.prePublishSteps;
            this.publishTools = builder.publishTools;
        }

        @Override
        public final io.github.cdklabs.projen.release.CodeArtifactOptions getCodeArtifactOptions() {
            return this.codeArtifactOptions;
        }

        @Override
        public final java.lang.String getDistTag() {
            return this.distTag;
        }

        @Override
        public final java.lang.String getNpmTokenSecret() {
            return this.npmTokenSecret;
        }

        @Override
        public final java.lang.String getRegistry() {
            return this.registry;
        }

        @Override
        public final java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> getPostPublishSteps() {
            return this.postPublishSteps;
        }

        @Override
        public final java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> getPrePublishSteps() {
            return this.prePublishSteps;
        }

        @Override
        public final io.github.cdklabs.projen.github.workflows.Tools getPublishTools() {
            return this.publishTools;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCodeArtifactOptions() != null) {
                data.set("codeArtifactOptions", om.valueToTree(this.getCodeArtifactOptions()));
            }
            if (this.getDistTag() != null) {
                data.set("distTag", om.valueToTree(this.getDistTag()));
            }
            if (this.getNpmTokenSecret() != null) {
                data.set("npmTokenSecret", om.valueToTree(this.getNpmTokenSecret()));
            }
            if (this.getRegistry() != null) {
                data.set("registry", om.valueToTree(this.getRegistry()));
            }
            if (this.getPostPublishSteps() != null) {
                data.set("postPublishSteps", om.valueToTree(this.getPostPublishSteps()));
            }
            if (this.getPrePublishSteps() != null) {
                data.set("prePublishSteps", om.valueToTree(this.getPrePublishSteps()));
            }
            if (this.getPublishTools() != null) {
                data.set("publishTools", om.valueToTree(this.getPublishTools()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.release.NpmPublishOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NpmPublishOptions.Jsii$Proxy that = (NpmPublishOptions.Jsii$Proxy) o;

            if (this.codeArtifactOptions != null ? !this.codeArtifactOptions.equals(that.codeArtifactOptions) : that.codeArtifactOptions != null) return false;
            if (this.distTag != null ? !this.distTag.equals(that.distTag) : that.distTag != null) return false;
            if (this.npmTokenSecret != null ? !this.npmTokenSecret.equals(that.npmTokenSecret) : that.npmTokenSecret != null) return false;
            if (this.registry != null ? !this.registry.equals(that.registry) : that.registry != null) return false;
            if (this.postPublishSteps != null ? !this.postPublishSteps.equals(that.postPublishSteps) : that.postPublishSteps != null) return false;
            if (this.prePublishSteps != null ? !this.prePublishSteps.equals(that.prePublishSteps) : that.prePublishSteps != null) return false;
            return this.publishTools != null ? this.publishTools.equals(that.publishTools) : that.publishTools == null;
        }

        @Override
        public final int hashCode() {
            int result = this.codeArtifactOptions != null ? this.codeArtifactOptions.hashCode() : 0;
            result = 31 * result + (this.distTag != null ? this.distTag.hashCode() : 0);
            result = 31 * result + (this.npmTokenSecret != null ? this.npmTokenSecret.hashCode() : 0);
            result = 31 * result + (this.registry != null ? this.registry.hashCode() : 0);
            result = 31 * result + (this.postPublishSteps != null ? this.postPublishSteps.hashCode() : 0);
            result = 31 * result + (this.prePublishSteps != null ? this.prePublishSteps.hashCode() : 0);
            result = 31 * result + (this.publishTools != null ? this.publishTools.hashCode() : 0);
            return result;
        }
    }
}
